@@ -1,14 +1,11 @@
-import os
 import pytest
 
-from s3contents.tests.utils import GCS_TEST
 from s3contents import GCSContentsManager
 from s3contents.ipycompat import TestContentsManager
 
 
-@GCS_TEST
+@pytest.mark.gcs
 class GCSContentsManagerTestCase(TestContentsManager):
-
     def setUp(self):
         """
         This setup is a hardcoded to run on my laptop and GCP account :)
@@ -16,7 +13,8 @@ class GCSContentsManagerTestCase(TestContentsManager):
         self.contents_manager = GCSContentsManager(
             project="continuum-compute",
             token="~/.config/gcloud/application_default_credentials.json",
-            bucket="gcsfs-test")
+            bucket="gcsfs-test",
+        )
 
         self.tearDown()
 
@@ -29,8 +27,8 @@ class GCSContentsManagerTestCase(TestContentsManager):
 
     def make_dir(self, api_path):
         self.contents_manager.new(
-            model={"type": "directory"},
-            path=api_path,)
+            model={"type": "directory"}, path=api_path,
+        )
 
 
 # This needs to be removed or else we'll run the main IPython tests as well.
