@@ -1,13 +1,14 @@
-from s3contents.ipycompat import TestContentsManager
+import pytest
 
 from s3contents import S3ContentsManager
+from s3contents.ipycompat import TestContentsManager
 
 
+@pytest.mark.minio
 class S3ContentsManagerTestCase(TestContentsManager):
-
     def setUp(self):
         """
-        This setup is a hardcoded to the use a little minio server that run on travis CI or play.minio.io:9000
+        This setup is a hardcoded to the use a minio server running in localhost
         """
         self.contents_manager = S3ContentsManager(
             access_key_id="access-key",
@@ -16,7 +17,8 @@ class S3ContentsManagerTestCase(TestContentsManager):
             bucket="notebooks",
             # endpoint_url="https://play.minio.io:9000",
             # bucket="s3contents-test2",
-            signature_version="s3v4")
+            signature_version="s3v4",
+        )
 
         self.tearDown()
 
@@ -29,8 +31,8 @@ class S3ContentsManagerTestCase(TestContentsManager):
 
     def make_dir(self, api_path):
         self.contents_manager.new(
-            model={"type": "directory"},
-            path=api_path,)
+            model={"type": "directory"}, path=api_path,
+        )
 
 
 # This needs to be removed or else we'll run the main IPython tests as well.
